@@ -17,8 +17,6 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: CopyJob.h,v 1.32 2011/04/29 04:58:27 lav Exp $ */
-
 #ifndef COPYJOB_H
 #define COPYJOB_H
 
@@ -37,6 +35,7 @@ protected:
    bool no_status;
    bool no_status_on_write;
    bool clear_status_on_write;
+   bool quiet;
 
    void SetDispName();
 
@@ -50,6 +49,7 @@ public:
    void NoStatusOnWrite() { no_status_on_write=true; }
    void ClearStatusOnWrite() { clear_status_on_write=true; }
    bool HasStatus() const { return !no_status; }
+   void Quiet(bool q) { quiet=q; }
 
    int Do();
    int Done() { return done; }
@@ -66,7 +66,8 @@ public:
    bool Error() { return c->Error(); }
    const char *ErrorText() { return c->ErrorText(); }
    double GetTimeSpent() { return c->GetTimeSpent(); }
-   virtual off_t GetBytesCount() { return c->GetBytesCount(); }
+   off_t GetBytesCount() { return c->GetBytesCount(); }
+   double GetTransferRate() { return c->GetTransferRate(); }
    off_t GetSize() { return c->GetSize(); }
    off_t GetPos()  { return c->GetPos(); }
    float GetRate() { return c->GetRate(); }
@@ -110,12 +111,14 @@ protected:
    int errors;
    int count;
    off_t bytes;
+   TimeDate transfer_start_ts;
    double time_spent;
    const char *op;
    bool no_status;
    xstring_c cwd;
    bool cont;
    bool ascii;
+   bool quiet;
    Ref<ArgV> args;
 
    virtual void NextFile() = 0;
@@ -143,8 +146,10 @@ public:
 
    void Ascii() { ascii=true; }
 
-   double GetTimeSpent() { return time_spent; }
-   off_t GetBytesCount() { return bytes; }
+   double GetTimeSpent() { return time_spent+(waiting.count()>0?now-transfer_start_ts:0.); }
+   off_t GetBytesCount() { return bytes+Job::GetBytesCount(); }
+
+   void Quiet(bool q) { quiet=q; }
 };
 
 #endif // COPYJOB_H
