@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2012 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,6 +45,10 @@ public:
    void NoInhibitTilde() { inhibit_tilde=false; }
    void CaseFold() { casefold=true; }
 
+   void MatchPeriod(bool y) { match_period=y; }
+   void InhibitTilde(bool y) { inhibit_tilde=y; }
+   void CaseFold(bool y) { casefold=y; }
+
    static bool HasWildcards(const char *);
    static void UnquoteWildcards(char *);
 };
