@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2017 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -131,9 +131,8 @@ private:
    TimeDate transfer_start_ts;
 
    /* root_transfer_count is the global counter in the root mirror,
-    * and weight of a non-root mirror otherwise. */
+    * and weight of a non-root mirror in global transfer_count otherwise. */
    int	 root_transfer_count;
-   int	 &transfer_count; // reference to root_mirror->root_transfer_count
 
    int	 flags;
    recursion_mode_t recursion_mode;
@@ -181,21 +180,15 @@ private:
 	    const char *relative_dir);
    void HandleListInfo(SMTaskRef<ListInfo>& list_info,Ref<FileSet>& set,Ref<FileSet> *fsx=0);
 
+   void MirrorStarted();
+   void MirrorFinished();
    void TransferStarted(class CopyJob *cp);
    void JobStarted(Job *j);
    void TransferFinished(Job *j);
    void JobFinished(Job *j);
 
-   off_t GetBytesCount() {
-      long long bytes_count=Job::GetBytesCount();
-      if(!parent_mirror) {
-	 // bytes_transferred is cumulative over the mirror tree,
-	 // add it on the top only
-	 bytes_count+=bytes_transferred;
-      }
-      return bytes_count;
-   }
-   double GetTimeSpent() { return transfer_time_elapsed+(transfer_count>0?now-root_mirror->transfer_start_ts:0.); }
+   off_t GetBytesCount();
+   double GetTimeSpent();
 
 public:
    enum
