@@ -551,7 +551,8 @@ got_fileset:
       if(!result)
 	 result=new FileSet;
 
-      result->Exclude(exclude_prefix,exclude);
+      if(exclude)
+	 result->Exclude(exclude_prefix,exclude,excluded.get_non_const());
       result->rewind();
       for(file=result->curr(); file!=0; file=result->next())
       {
