@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2017 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -398,7 +398,7 @@ static ResType lftp_vars[] = {
    {"xfer:backup-suffix",	 "~%Y%m%d%H%M%S~",0,ResMgr::NoClosure},
 
    // deprecated settings
-   {"xfer:log",		   "log:enable/xfer",   0,ResMgr::AliasValidate},
+   {"xfer:log",		   "log:enabled/xfer",   0,ResMgr::AliasValidate},
    {"xfer:log-file",	   "log:file/xfer",	0,ResMgr::AliasValidate},
    {"xfer:max-log-size",   "log:max-size/xfer",	0,ResMgr::AliasValidate},
 
